Overview
========

ChaosMagPy is a simple Python package for evaluating the
`CHAOS <http://www.spacecenter.dk/files/magnetic-models/CHAOS-6/>`_ geomagnetic
field model. To get quickly started, download a complete working example
including the latest model `here <http://www.spacecenter.dk/files/magnetic-models/CHAOS-6/chaosmagpy_package.zip>`_.

References
----------

*Finlay, C.C., Olsen, N., Kotsiaros, S., Gillet, N. and Toeffner-Clausen, L.
(2016)*, Recent geomagnetic secular variation from Swarm and ground observatories
as estimated in the CHAOS-6 geomagnetic field model Earth Planets Space,
Vol 68, 112. doi: 10.1186/s40623-016-0486-1

*Olsen, N., Luehr, H., Finlay, C.C., Sabaka, T. J., Michaelis, I., Rauberg, J.
and Toeffner-Clausen, L. (2014)*, The CHAOS-4 geomagnetic field model,
Geophys. J. Int., Vol 197, 815-827, doi: 10.1093/gji/ggu033.

*Olsen, N.,  Luehr, H.,  Sabaka, T.J.,  Mandea, M. ,Rother, M., Toeffner-Clausen, L.
and Choi, S. (2006)*, CHAOS — a model of Earth's magnetic field derived from CHAMP,
Ørsted, and SAC-C magnetic satellite data, Geophys. J. Int., vol. 166 67-75

Documentation
-------------

The latest documentation of the package is available on
`Read the Docs <https://chaosmagpy.readthedocs.io/en/latest/>`_. 
